/* USB setup recipient values */
#define USB_RQ_RCPT_MASK		0x1f
#define USB_RQ_RCPT_DEVICE		0
#define USB_RQ_RCPT_INTERFACE		1
#define USB_RQ_RCPT_ENDPOINT		2

/* USB request in setup_data[] */
#define USB_RQ_TYPE			0x0
#define USB_RQ_REQ			0x1
#define USB_RQ_VALUE_L			0x2
#define USB_RQ_VALUE_H			0x3
#define USB_RQ_INDEX_L			0x4
#define USB_RQ_INDEX_H			0x5
#define USB_RQ_LENGTH_L			0x6
#define USB_RQ_LENGTH_H			0x7

/* USB request type values */
#define USB_RQ_TYPE_MASK		0x60
#define USB_RQ_TYPE_STANDARD		(0<<5)
#define USB_RQ_TYPE_CLASS		(1<<5)
#define USB_RQ_TYPE_VENDOR		(2<<5)

/* USB direction values: */
#define USB_RQ_DIR_MASK			0x80
#define USB_RQ_DIR_HOST_TO_DEVICE	(0<<7)
#define USB_RQ_DIR_DEVICE_TO_HOST	(1<<7)

/* USB Standard Requests */
#define USB_RQ_GET_STATUS		0
#define USB_RQ_CLEAR_FEATURE		1
#define USB_RQ_SET_FEATURE		3
#define USB_RQ_SET_ADDRESS		5
#define USB_RQ_GET_DESCRIPTOR		6
#define USB_RQ_SET_DESCRIPTOR		7
#define USB_RQ_GET_CONFIGURATION	8
#define USB_RQ_SET_CONFIGURATION	9
#define USB_RQ_GET_INTERFACE		10
#define USB_RQ_SET_INTERFACE		11
#define USB_RQ_SYNCH_FRAME		12

/* USB HID Requests */
#define USB_RQ_HID_GET_REPORT		0x01
#define USB_RQ_HID_GET_IDLE		0x02
#define USB_RQ_HID_GET_PROTOCOL		0x03
#define USB_RQ_HID_SET_REPORT		0x09
#define USB_RQ_HID_SET_IDLE		0x0a
#define USB_RQ_HID_SET_PROTOCOL		0x0b

/* USB COMM Requests */
#define USB_RQ_COMM_COMMAND		0x0
#define USB_RQ_COMM_RESPONSE		0x1
#define USB_RQ_COMM_SET_FEATURE		0x2
#define USB_RQ_COMM_GET_FEATURE		0x3
#define USB_RQ_COMM_CLEAR_FEATURE	0x4
#define USB_RQ_COMM_SET_LINE		0x20
#define USB_RQ_COMM_GET_LINE		0x21
#define USB_RQ_COMM_SET_CONTROL		0x22
#define USB_RQ_COMM_SEND_BREAK		0x23

/* USB AUDIO Requests */
#define USB_RQ_AUDIO_SET_CUR		0x01
#define USB_RQ_AUDIO_GET_CUR		0x81
#define USB_RQ_AUDIO_SET_MIN		0x02
#define USB_RQ_AUDIO_GET_MIN		0x82
#define USB_RQ_AUDIO_SET_MAX		0x03
#define USB_RQ_AUDIO_GET_MAX		0x83
#define USB_RQ_AUDIO_SET_RES		0x04
#define USB_RQ_AUDIO_GET_RES		0x84
#define USB_RQ_AUDIO_SET_MEM		0x05
#define USB_RQ_AUDIO_GET_MEM		0x85
#define USB_RQ_AUDIO_GET_STAT		0xff

/* ----- usb162 driver interface */

/* GPIOR2 bit definition */
#define USB162_RECV_RESET		0
#define USB162_RX_SEND_EMPTY		1
#define USB162_RX_SEND_REQ		2

extern int8_t usb_connected;

extern void usbPoll();
extern void usbInit();
extern int8_t (* usb_user_setup)(uint8_t *, uint8_t *);
